==> resh-5.3.0.6-py3-none-any.whl: reface/dashboard/monitor.py <==
from django.contrib.auth.mixins import LoginRequiredMixin
from django.views.generic import TemplateView
from dali.gear import general as d1

from resh.protocols.payloads.dali import Dali2Event, DaliCommand, Dali2Command
from resh.protocols.payloads.rapida import ServicePacket
from reface.dashboard.models import Boxes


class Dali(LoginRequiredMixin, TemplateView):
    template_name = 'monitor/dali.html'

    def get(self, request, box_id, module_id, channel_id, *args, **kwargs):
        # room = '%s/%s/%s/dali' % (box_id, module_id, channel_id)

        return self.render_to_response(
            context=dict(
                name=Boxes.instance.name, box=box_id, module=module_id, channel=channel_id,
                marks=[[DaliCommand.mark, Dali2Command.mark, Dali2Event.mark, ServicePacket.mark]],
                names=[[d1.DAPC.__name__, d1.Off.__name__], [d1.GoToScene.__name__, d1.GoToLastActiveLevel.__name__],
                       [d1.RecallMinLevel.__name__, d1.RecallMaxLevel.__name__], [d1.StepDown.__name__, d1.StepUp.__name__],
                       [d1.QueryStatus.__name__, d1.QueryActualLevel.__name__], [d1.IdentifyDevice.__name__]],
                addresses=[range(i*8, i*8+8) for i in range(0, 8)],
                groups=[range(i*4, i*4+4) for i in range(0, 4)],
                # bus=dict(name=bam.Dali.__name__.lower(), items=items),
                socket=f'/rapida/ws/monitor/{box_id}/{module_id}/{channel_id}/dali/',
                box_name=Boxes.instance[int(box_id)].name
            ),
        )

==> resh-5.5.0.95-py3-none-any.whl: reface/dashboard/monitor.py <==
from django.contrib.auth.mixins import LoginRequiredMixin
from django.views.generic import TemplateView
from dali.gear import general as d1

from resh.protocols.payloads.dali import Dali2Event, DaliCommand, Dali2Command
from resh.protocols.payloads.rapida import ServicePacket
from reface.dashboard.models import Boxes


class Dali(LoginRequiredMixin, TemplateView):
    template_name = 'monitor/dali.html'

    def get(self, request, box_id, module_id, channel_id, *args, **kwargs):
        # room = '%s/%s/%s/dali' % (box_id, module_id, channel_id)

        return self.render_to_response(
            context=dict(
                name=Boxes.instance.name, box=box_id, module=module_id, channel=channel_id,
                marks=[[DaliCommand.mark, Dali2Command.mark, Dali2Event.mark, ServicePacket.mark]],
                names=[[d1.DAPC.__name__, d1.Off.__name__], [d1.GoToScene.__name__, d1.GoToLastActiveLevel.__name__],
                       [d1.RecallMinLevel.__name__, d1.RecallMaxLevel.__name__], [d1.StepDown.__name__, d1.StepUp.__name__],
                       [d1.QueryStatus.__name__, d1.QueryActualLevel.__name__], [d1.IdentifyDevice.__name__]],
                addresses=[range(i*8, i*8+8) for i in range(0, 8)],
                groups=[range(i*4, i*4+4) for i in range(0, 4)],
                # bus=dict(name=bam.Dali.__name__.lower(), items=items),
                socket=f'/rapida/ws/monitor/{box_id}/D/{module_id}/{channel_id}/dali/',
                box_name=Boxes.instance[int(box_id)].name
            ),
        )
